@@ -9,24 +9,6 @@ import pyBigWig
 from pysam import FastaFile
 from scipy.ndimage import gaussian_filter1d
 
-#查看环境下所有可用gpu
-# 注意，该步骤会先生成后删除一个中间文件。
-def get_available_gpu_in_this_equipment():
-    import os
-    if not os.path.exists('gpu_tmp'):
-        os.system ( 'nvidia-smi -q -d Memory |grep -A4 GPU |grep Free > gpu_tmp')
-        memory_gpu = [int(x.split()[2]) for x in open( 'gpu_tmp', 'r' ).readlines()]
-        gpu_list = []
-        for i in range(len(memory_gpu)):
-            if memory_gpu[i] >= 8192:
-                gpu_list.append('/gpu:'+str(i))
-        os.system( 'rm gpu_tmp')
-        if len(gpu_list) == 0:
-            raise Exception('gpu info','no gpu')
-        return gpu_list
-    else:
-        raise Exception("file exits", 'gpu_tmp')
-
 
 #辅助函数，用于one-hot编码
 #用此函数对100万条1000长度的序列编码需要约700秒（GPU02节点）
